==> gwget2-0.6.tar.gz: gwget2-0.6/include/main_window_cb.h <==
#ifndef _MAIN_WINDOW_CB_H
#define _MAIN_WINDOW_CB_H
#include "gwget_data.h"

void on_quit1_activate(GtkWidget *widget, gpointer data);
void on_about1_activate(GtkWidget *widget, gpointer data);

void on_boton_nuevo_clicked(GtkWidget *widget, gpointer data);
void on_boton_cancelar_clicked(GtkWidget *widget,gpointer data);
void on_about1_close(GtkWidget *widget, gpointer data);
void new_download(GwgetData *gwgetdata);
/* Preferences callbacks */
void on_pref_cancel_button_clicked(GtkWidget *widget,gpointer data);
void on_pref_ok_button_clicked(GtkWidget *widget,gpointer data);
void on_fs_cancel_button_clicked(GtkWidget *widget, gpointer data);
void on_fs_ok_button_clicked(GtkWidget *widget, gpointer data);
void on_boton_pref_clicked(GtkWidget *widget, gpointer data);
void on_browse_save_in_button_clicked(GtkWidget *widget, gpointer data);
void stop_all_downloads(void);
/* Popup menu in treeview callbacks (Not implemented yet) */
gboolean on_treeview1_button_press_event(GtkWidget *widget, GdkEventButton *event,gpointer user_data);

/* Stop toolbar button callback */
void on_stop_button_clicked (GtkWidget *widget, gpointer data);
/* Selection Change in treeview callback ( Not yet implemented ) */
void tree_selection_changed_cb(GtkTreeSelection *selection, gpointer data);

/* Popup options */
void on_popup_pause_button_clicked(GtkWidget *widget, gpointer data);
void on_popup_continue_activate(GtkWidget *widget, gpointer data);
void on_cancel_download_activate(GtkWidget *widget,gpointer data);
void on_remove_completed_activate(GtkWidget *widget, gpointer data);

#endif

==> gwget2_0.7.orig.tar.gz: gwget2-0.7.orig/include/main_window_cb.h <==
#ifndef _MAIN_WINDOW_CB_H
#define _MAIN_WINDOW_CB_H
#include "gwget_data.h"

void on_quit1_activate(GtkWidget *widget, gpointer data);
void on_about1_activate(GtkWidget *widget, gpointer data);

void on_boton_nuevo_clicked(GtkWidget *widget, gpointer data);
void on_boton_cancelar_clicked(GtkWidget *widget,gpointer data);
void on_about1_close(GtkWidget *widget, gpointer data);
void new_download(GwgetData *gwgetdata);
/* Preferences callbacks */
void on_pref_cancel_button_clicked(GtkWidget *widget,gpointer data);
void on_pref_ok_button_clicked(GtkWidget *widget,gpointer data);
void on_fs_cancel_button_clicked(GtkWidget *widget, gpointer data);
void on_fs_ok_button_clicked(GtkWidget *widget, gpointer data);
void on_boton_pref_clicked(GtkWidget *widget, gpointer data);
void on_browse_save_in_button_clicked(GtkWidget *widget, gpointer data);
void stop_all_downloads(void);
/* Popup menu in treeview callbacks */
gboolean on_treeview1_button_press_event(GtkWidget *widget, GdkEventButton *event,gpointer user_data);

/* Stop toolbar button callback */
void on_stop_button_clicked (GtkWidget *widget, gpointer data);
/* Selection Change in treeview callback ( Not yet implemented ) */
void tree_selection_changed_cb(GtkTreeSelection *selection, gpointer data);

/* Popup options */
void on_popup_pause_button_clicked(GtkWidget *widget, gpointer data);
void on_popup_continue_activate(GtkWidget *widget, gpointer data);
void on_cancel_download_activate(GtkWidget *widget,gpointer data);
void on_remove_completed_activate(GtkWidget *widget, gpointer data);
void on_remove_notrunning_activate(GtkWidget *widget, gpointer data);
void on_remove_all_activate(GtkWidget *widget, gpointer data);


#endif
